@@ -43,6 +43,10 @@ rlang::`%||%`
 #' @importFrom rlang "%|%"
 rlang::`%|%`
 
+#' @export
+#' @importFrom rlang ":="
+rlang::`:=`
+
 #' @export
 #' @importFrom ipmisc tibble
 ipmisc::tibble
